@@ -1,35 +1,3 @@
-# nocov start
-warn_deprecated <- function(msg, id = msg) {
-  if (rlang::is_true(rlang::peek_option("lifecycle_disable_warnings"))) {
-    return(invisible(NULL))
-  }
-
-  if (!rlang::is_true(rlang::peek_option("lifecycle_repeat_warnings"))) {
-    if (rlang::env_has(deprecation_env, id)) {
-      return(invisible(NULL))
-    }
-
-    msg <- paste0(
-      msg,
-      "\n",
-      "This warning is displayed once per session."
-    )
-  }
-
-  rlang::env_poke(deprecation_env, id, TRUE)
-
-  if (rlang::is_true(rlang::peek_option("lifecycle_warnings_as_errors"))) {
-    signal <- .Defunct
-  } else {
-    signal <- .Deprecated
-  }
-
-  signal(msg = msg)
-}
-
-deprecation_env <- new.env(parent = emptyenv())
-# nocov end
-
 #' Deprecated functions
 #'
 #' @param x Other objects.
@@ -41,13 +9,6 @@ as.tsibble <- function(x, ...) {
   as_tsibble(x, ...)
 }
 
-#' @rdname deprecated
-#' @export
-#' @keywords internal
-pull_interval <- function(x) {
-  .Defunct("interval_pull()")
-}
-
 #' @rdname deprecated
 #' @export
 #' @keywords internal
@@ -70,8 +31,7 @@ use_id <- function(x, key) {
   key_quo <- enquo(key)
   if (quo_is_null(key_quo)) {
     return(character())
-  }
-  if (quo_is_call(key_quo)) {
+  } else if (quo_is_call(key_quo)) {
     call_fn <- call_name(key_quo)
     if (call_fn == "id") {
       res <- eval_tidy(get_expr(key_quo), env = child_env(get_env(key_quo), id = id))
@@ -89,7 +49,7 @@ use_id <- function(x, key) {
       return(res_vars)
     }
   }
-  vars_select(names(x), !! key_quo)
+  vars_select(names(x), !!key_quo)
 }
 
 abort_stretch_size <- function(...) {
@@ -99,11 +59,10 @@ abort_stretch_size <- function(...) {
   }
 }
 
-warn_gather <- function(..., pivot_longer = TRUE) {
+abort_gather <- function(..., pivot_longer = TRUE) {
   dots <- dots_list(...)
   if ("gather" %in% names(dots)) {
-    warn("Argument `gather` is deprecated, please use `pivot_longer` instead.")
-    dots$gather
+    abort("Argument `gather` is defunct, please use `pivot_longer` instead.")
   } else {
     pivot_longer
   }
