@@ -8,17 +8,18 @@ rename_join_tsibble <- function(x, y, by = NULL, suffix = c(".x", ".y")) {
 
   names <- paste0(common_names, suffix[1])
   names(common_names) <- names
-  rename_tsibble(x, !!! common_names)
+  rename_tsibble(x, !!!common_names)
 }
 
 #' @export
-left_join.tbl_ts <- function(
-  x, y, by = NULL, copy = FALSE, suffix = c(".x", ".y"), ...
-) {
-  tbl <- NextMethod()
+left_join.tbl_ts <- function(x, y, by = NULL, copy = FALSE,
+                             suffix = c(".x", ".y"), ...) {
+  res <- NextMethod()
   x <- rename_join_tsibble(x, y, by = by, suffix = suffix)
-  update_meta(tbl, x, ordered = is_ordered(x), interval = is_regular(x),
-    validate = if (NROW(tbl) > NROW(x)) TRUE else FALSE)
+  update_meta(res, x,
+    ordered = is_ordered(x), interval = is_regular(x),
+    validate = (NROW(res) > NROW(x)) || !is_tsibble(y)
+  )
 }
 
 #' @export
@@ -32,8 +33,9 @@ full_join.tbl_ts <- left_join.tbl_ts
 
 #' @export
 semi_join.tbl_ts <- function(x, ...) {
-  update_meta(NextMethod(), x, ordered = is_ordered(x), 
-    interval = is_regular(x), validate = FALSE)
+  update_meta(NextMethod(), x,
+    ordered = is_ordered(x), interval = is_regular(x), validate = FALSE
+  )
 }
 
 #' @export
