@@ -32,7 +32,8 @@ arrange.grouped_ts <- arrange.tbl_ts
 
 #' @rdname tsibble-tidyverse
 filter.tbl_ts <- function(.data, ..., .preserve = FALSE) {
-  by_row(filter, .data, ordered = is_ordered(.data),
+  by_row(filter, .data,
+    ordered = is_ordered(.data),
     interval = is_regular(.data), ..., .preserve = .preserve
   )
 }
@@ -44,10 +45,12 @@ slice.tbl_ts <- function(.data, ..., .preserve = FALSE) {
   if (length(pos) > 1) {
     abort("`slice()` only accepts one expression.")
   }
-  pos_df <- summarise(as_tibble(.data), !! ".pos_col" := list2(!! pos[[1]]))
+  pos_df <- summarise(as_tibble(.data), !!".pos_col" := list2(!!pos[[1]]))
   ascending <- all(map_lgl(pos_df[[".pos_col"]], validate_order))
-  by_row(slice, .data, ordered = ascending, interval = is_regular(.data), ...,
-    .preserve = .preserve)
+  by_row(slice, .data,
+    ordered = ascending, interval = is_regular(.data), ...,
+    .preserve = .preserve
+  )
 }
 
 #' @rdname tsibble-tidyverse
@@ -65,11 +68,11 @@ select.tbl_ts <- function(.data, ...) {
   }
 
   named <- list_is_named(lst_quos)
-  .data <- rename_tsibble(.data, !!! lst_quos[named])
+  .data <- rename_tsibble(.data, !!!lst_quos[named])
 
   lst_env <- map(lst_quos, quo_get_env)[named]
   lst_quos[named] <- as_quosures(names(lst_quos)[named], env = lst_env)
-  select_tsibble(.data, !!! lst_quos)
+  select_tsibble(.data, !!!lst_quos)
 }
 
 #' @export
@@ -116,9 +119,10 @@ mutate.tbl_ts <- function(.data, ...) {
     mut_data <- retain_tsibble(mut_data, key(.data), index(.data))
   }
   build_tsibble(
-    mut_data, key = !! key_vars(.data),
-    key_data = if (val_key) NULL else key_data(.data), index = !! index(.data),
-    index2 = !! index2(.data), ordered = is_ordered(.data), interval = interval,
+    mut_data,
+    key = !!key_vars(.data),
+    key_data = if (val_key) NULL else key_data(.data), index = !!index(.data),
+    index2 = !!index2(.data), ordered = is_ordered(.data), interval = interval,
     validate = FALSE, .drop = is_key_dropped(.data)
   )
 }
@@ -127,10 +131,10 @@ mutate.tbl_ts <- function(.data, ...) {
 #' @export
 transmute.tbl_ts <- function(.data, ...) {
   lst_quos <- enquos(..., .named = TRUE)
-  mut_data <- mutate(.data, !!! lst_quos)
+  mut_data <- mutate(.data, !!!lst_quos)
   idx_key <- c(key_vars(.data), index_var(.data))
   vec_names <- union(idx_key, names(lst_quos))
-  select_tsibble(mut_data, !!! vec_names, validate = FALSE)
+  select_tsibble(mut_data, !!!vec_names, validate = FALSE)
 }
 
 #' @export
@@ -138,8 +142,8 @@ transmute.grouped_ts <- function(.data, ...) {
   res <- NextMethod()
   # keeping index and key
   idx_key <- c(key_vars(.data), index_var(.data))
-  tsbl <- select_tsibble(ungroup(.data), !!! idx_key, validate = FALSE)
-  dplyr::bind_cols(tsbl, res[, !(names(res) %in% names(tsbl))])
+  tsbl <- select_tsibble(ungroup(.data), !!!idx_key, validate = FALSE)
+  bind_cols(tsbl, res[, !(names(res) %in% names(tsbl))])
 }
 
 #' @rdname tsibble-tidyverse
@@ -147,7 +151,7 @@ transmute.grouped_ts <- function(.data, ...) {
 #' library(dplyr, warn.conflicts = FALSE)
 #' # Sum over sensors
 #' pedestrian %>%
-#'   index_by() %>% 
+#'   index_by() %>%
 #'   summarise(Total = sum(Count))
 #' # shortcut
 #' pedestrian %>%
@@ -171,17 +175,18 @@ summarise.tbl_ts <- function(.data, ...) {
   nonkey <- setdiff(names(lst_quos), c(key_vars(.data), idx_chr, idx2_chr))
   nonkey_quos <- lst_quos[nonkey]
 
-  grped_data <- as_tibble(index_by(.data, !! idx2))
+  grped_data <- as_tibble(index_by(.data, !!idx2))
   sum_data <-
     group_by(
-      summarise(grped_data, !!! nonkey_quos),
-      !!! head(groups(grped_data), -2) # remove index2 and last grp
+      summarise(grped_data, !!!nonkey_quos),
+      !!!head(groups(grped_data), -2) # remove index2 and last grp
     )
   if (identical(idx, idx2)) int <- is_regular(.data) else int <- TRUE
   grps <- setdiff(group_vars(.data), idx2_chr)
 
   build_tsibble(
-    sum_data, key = !! grps, index = !! idx2, ordered = TRUE, interval = int,
+    sum_data,
+    key = !!grps, index = !!idx2, ordered = TRUE, interval = int,
     validate = FALSE
   )
 }
@@ -189,11 +194,13 @@ summarise.tbl_ts <- function(.data, ...) {
 #' @importFrom dplyr group_by_drop_default
 #' @export
 group_by.tbl_ts <- function(.data, ..., add = FALSE,
-  .drop = group_by_drop_default(.data)) {
+                            .drop = group_by_drop_default(.data)) {
   lst_quos <- enquos(..., .named = TRUE)
   grp_vars <- names(lst_quos)
   if (add) grp_vars <- union(group_vars(.data), grp_vars)
-  if (is_empty(grp_vars)) return(.data)
+  if (is_empty(grp_vars)) {
+    return(.data)
+  }
   index <- index_var(.data)
   if (index %in% grp_vars) {
     err <- sprintf("Column `%s` (index) can't be a grouping variable for a tsibble.", index)
@@ -201,7 +208,7 @@ group_by.tbl_ts <- function(.data, ..., add = FALSE,
     abort(paste_inline(err, hint))
   }
 
-  grp_key <- identical(grp_vars, key_vars(.data)) && 
+  grp_key <- identical(grp_vars, key_vars(.data)) &&
     identical(.drop, key_drop_default(.data))
   if (grp_key) {
     grped_tbl <- new_grouped_df(.data, groups = key_data(.data))
@@ -209,15 +216,19 @@ group_by.tbl_ts <- function(.data, ..., add = FALSE,
     grped_tbl <- NextMethod()
   }
   build_tsibble(
-    grped_tbl, key = !! key_vars(.data), 
+    grped_tbl,
+    key = !!key_vars(.data),
     key_data = if (grp_key) key_data(.data) else NULL,
-    index = !! index(.data), index2 = !! index2(.data),
+    index = !!index(.data), index2 = !!index2(.data),
     ordered = is_ordered(.data), interval = interval(.data), validate = FALSE
   )
 }
 
 #' Group by key variables
 #'
+#' @description
+#' \Sexpr[results=rd, stage=render]{tsibble:::lifecycle("stable")}
+#'
 #' @param .data A `tbl_ts` object.
 #' @param ... Ignored.
 #' @inheritParams dplyr::group_by
@@ -226,14 +237,15 @@ group_by.tbl_ts <- function(.data, ..., add = FALSE,
 #' tourism %>%
 #'   group_by_key()
 group_by_key <- function(.data, ..., .drop = key_drop_default(.data)) {
-  group_by(.data, !!! key(.data), .drop = .drop)
+  group_by(.data, !!!key(.data), .drop = .drop)
 }
 
 #' @export
 ungroup.grouped_ts <- function(x, ...) {
   tbl <- ungroup(as_tibble(x))
   build_tsibble(
-    tbl, key_data = key_data(x), index = !! index(x),
+    tbl,
+    key_data = key_data(x), index = !!index(x),
     ordered = is_ordered(x), interval = interval(x), validate = FALSE
   )
 }
