@@ -1,5 +1,8 @@
 #' A shorthand for filtering time index for a tsibble
 #'
+#' @description
+#' \Sexpr[results=rd, stage=render]{tsibble:::lifecycle("maturing")}
+#'
 #' This shorthand respects time zones and encourages compact expressions.
 #'
 #' @param .data A tsibble.
@@ -11,12 +14,12 @@
 #' `yearquarter`/`yearqtr`, `hms`/`difftime` & `numeric`.
 #' @inheritParams dplyr::filter
 #'
-#' @section System Time Zone ("Europe/London"): 
-#' There is a known issue of an extra hour gained for a machine setting time 
+#' @section System Time Zone ("Europe/London"):
+#' There is a known issue of an extra hour gained for a machine setting time
 #' zone to "Europe/London", regardless of the time zone associated with
-#' the POSIXct inputs. It relates to *anytime* and *Boost*. Use `Sys.timezone()` 
+#' the POSIXct inputs. It relates to *anytime* and *Boost*. Use `Sys.timezone()`
 #' to check if the system time zone is "Europe/London". It would be recommended to
-#' change the global environment "TZ" to other equivalent names: GB, GB-Eire, 
+#' change the global environment "TZ" to other equivalent names: GB, GB-Eire,
 #' Europe/Belfast, Europe/Guernsey, Europe/Isle_of_Man and Europe/Jersey as
 #' documented in `?Sys.timezone()`, using `Sys.setenv(TZ = "GB")` for example.
 #'
@@ -25,7 +28,7 @@
 #' @examples
 #' # from the starting time to the end of Feb, 2015
 #' pedestrian %>%
-#'   filter_index(~ "2015-02")
+#'   filter_index(~"2015-02")
 #'
 #' # entire Feb 2015, & from the beginning of Aug 2016 to the end
 #' pedestrian %>%
@@ -33,29 +36,32 @@
 #'
 #' # multiple time windows
 #' pedestrian %>%
-#'   filter_index(~ "2015-02", "2015-08" ~ "2015-09", "2015-12" ~ "2016-02")
+#'   filter_index(~"2015-02", "2015-08" ~ "2015-09", "2015-12" ~ "2016-02")
 #'
 #' # entire 2015
 #' pedestrian %>%
 #'   filter_index("2015")
 #'
 #' # specific
-#' pedestrian %>% 
+#' pedestrian %>%
 #'   filter_index("2015-03-23" ~ "2015-10")
-#' pedestrian %>% 
+#' pedestrian %>%
 #'   filter_index("2015-03-23" ~ "2015-10-31")
-#' pedestrian %>% 
+#' pedestrian %>%
 #'   filter_index("2015-03-23 10" ~ "2015-10-31 12")
 filter_index <- function(.data, ..., .preserve = FALSE) {
   idx <- index(.data)
-  filter(.data, time_in(!! idx, ...), .preserve = .preserve)
+  filter(.data, time_in(!!idx, ...), .preserve = .preserve)
 }
 
 #' If time falls in the ranges using compact expressions
 #'
+#' @description
+#' \Sexpr[results=rd, stage=render]{tsibble:::lifecycle("maturing")}
+#'
 #' This function respects time zone and encourages compact expressions.
 #'
-#' @param x A vector of time index, such as classes `POSIXct`, `Date`, `yearweek`, 
+#' @param x A vector of time index, such as classes `POSIXct`, `Date`, `yearweek`,
 #' `yearmonth`, `yearquarter`, `hms`/`difftime`, and `numeric`.
 #' @inheritParams filter_index
 #'
@@ -65,17 +71,17 @@ filter_index <- function(.data, ..., .preserve = FALSE) {
 #' @export
 #' @examples
 #' x <- unique(pedestrian$Date_Time)
-#' lgl <- time_in(x, ~ "2015-02", "2015-08" ~ "2015-09", "2015-12" ~ "2016-02")
+#' lgl <- time_in(x, ~"2015-02", "2015-08" ~ "2015-09", "2015-12" ~ "2016-02")
 #' lgl[1:10]
 #' # more specific
 #' lgl2 <- time_in(x, "2015-03-23 10" ~ "2015-10-31 12")
 #' lgl2[1:10]
 #'
 #' library(dplyr)
-#' pedestrian %>% 
+#' pedestrian %>%
 #'   filter(time_in(Date_Time, "2015-03-23 10" ~ "2015-10-31 12"))
-#' pedestrian %>% 
-#'   filter(time_in(Date_Time, "2015")) %>% 
+#' pedestrian %>%
+#'   filter(time_in(Date_Time, "2015")) %>%
 #'   mutate(Season = ifelse(
 #'     time_in(Date_Time, "2015-03" ~ "2015-08"),
 #'     "Autumn-Winter", "Spring-Summer"
@@ -83,9 +89,11 @@ filter_index <- function(.data, ..., .preserve = FALSE) {
 time_in <- function(x, ...) {
   formulas <- list2(...)
   n <- length(formulas)
-  if (n == 0) return(!logical(length(x)))
+  if (n == 0) {
+    return(!logical(length(x)))
+  }
 
-  if (lubridate::is.POSIXct(x)) {
+  if (is.POSIXct(x)) {
     local_tz <- Sys.timezone()
     if ("Europe/London" %in% local_tz) {
       warn("System time zone: \"Europe/London\".\nIt may yield an unexpected output. Please see `?filter_index` for details.")
@@ -104,10 +112,9 @@ time_in <- function(x, ...) {
     lgl[[i]] <- eval_bare(x >= lhs[[i]] & x < rhs[[i]])
   }
 
-  purrr::reduce(lgl, `|`)
+  reduce(lgl, `|`)
 }
 
-#' @importFrom stats start end
 start.numeric <- function(x, y = NULL, ...) {
   if (is_null(y)) {
     min(x)
@@ -151,8 +158,8 @@ start.Date <- function(x, y = NULL, ...) {
     min(x)
   } else {
     abort_not_chr(y, class = "Date")
-    anytime::assertDate(y)
-    y <- anytime::utcdate(y, tz = "UTC")
+    assertDate(y)
+    y <- utcdate(y, tz = "UTC")
     attr(y, "tzone") <- NULL
     y
   }
@@ -160,26 +167,26 @@ start.Date <- function(x, y = NULL, ...) {
 
 end.Date <- function(x, y = NULL, ...) {
   if (is_null(y)) {
-    max(x) + lubridate::period(1, "day")
+    max(x) + period(1, "day")
   } else {
     abort_not_chr(y, class = "Date")
-    anytime::assertDate(y)
-    
+    assertDate(y)
+
     lgl_yrmth <- nchar(y) < 8 & nchar(y) > 4
     lgl_yr <- nchar(y) < 5
-    y <- anytime::utcdate(y, tz = "UTC")
+    y <- utcdate(y, tz = "UTC")
     attr(y, "tzone") <- NULL
     if (any(lgl_yrmth)) {
-      y[lgl_yrmth] <- lubridate::rollback(
-        y[lgl_yrmth] + lubridate::period(1, "month"), 
+      y[lgl_yrmth] <- rollback(
+        y[lgl_yrmth] + period(1, "month"),
         roll_to_first = TRUE
       )
     }
     if (any(lgl_yr)) {
-      y[lgl_yr] <- y[lgl_yr] + lubridate::period(1, "year")
+      y[lgl_yr] <- y[lgl_yr] + period(1, "year")
     }
     lgl_date <- !(lgl_yrmth | lgl_yr)
-    y[lgl_date] <- y[lgl_date] + lubridate::period(1, "day")
+    y[lgl_date] <- y[lgl_date] + period(1, "day")
     y
   }
 }
@@ -189,35 +196,35 @@ start.POSIXct <- function(x, y = NULL, ...) {
     min(x)
   } else {
     abort_not_chr(y, class = "POSIXct")
-    anytime::assertTime(y)
-    y <- anytime::utctime(y, tz = "UTC")
-    lubridate::force_tz(y, lubridate::tz(x), roll = TRUE)
+    assertTime(y)
+    y <- utctime(y, tz = "UTC")
+    force_tz(y, tz(x), roll = TRUE)
   }
 }
 
 end.POSIXct <- function(x, y = NULL, ...) {
   if (is_null(y)) {
-    max(x) + lubridate::period(1, "second")
+    max(x) + period(1, "second")
   } else {
     abort_not_chr(y, class = "POSIXct")
-    anytime::assertTime(y)
-    
+    assertTime(y)
+
     lgl_date <- nchar(y) > 7 & nchar(y) < 11
     lgl_yrmth <- nchar(y) < 9 & nchar(y) > 4
     lgl_yr <- nchar(y) < 5
-    y <- anytime::utctime(y, tz = "UTC")
-    y <- lubridate::force_tz(y, lubridate::tz(x), roll = TRUE)
+    y <- utctime(y, tz = "UTC")
+    y <- force_tz(y, tz(x), roll = TRUE)
     if (any(lgl_date)) {
-      y[lgl_date] <- y[lgl_date] + lubridate::period(1, "day")
+      y[lgl_date] <- y[lgl_date] + period(1, "day")
     }
     if (any(lgl_yrmth)) {
-      y[lgl_yrmth] <- lubridate::rollback(
-        y[lgl_yrmth] + lubridate::period(1, "month"), 
+      y[lgl_yrmth] <- rollback(
+        y[lgl_yrmth] + period(1, "month"),
         roll_to_first = TRUE
       )
     }
     if (any(lgl_yr)) {
-      y[lgl_yr] <- y[lgl_yr] + lubridate::period(1, "year")
+      y[lgl_yr] <- y[lgl_yr] + period(1, "year")
     }
     lgl_time <- !(lgl_date | lgl_yrmth | lgl_yr)
     y[lgl_time] <- y[lgl_time] + 1
