@@ -1,26 +1,32 @@
 #' Group by time index and collapse with `summarise()`
 #'
+#' @description
+#' \Sexpr[results=rd, stage=render]{tsibble:::lifecycle("stable")}
+#'
 #' `index_by()` is the counterpart of `group_by()` in temporal context, but it
 #' only groups the time index. The following operation is applied to each partition
-#' of the index, similar to `group_by()` but dealing with index only. 
-#' `index_by()` + `summarise()` will update the grouping index variable to be 
+#' of the index, similar to `group_by()` but dealing with index only.
+#' `index_by()` + `summarise()` will update the grouping index variable to be
 #' the new index. Use `ungroup()` to remove the index grouping vars.
 #'
 #' @param .data A `tbl_ts`.
-#' @param ... If empty, grouping the current index. Or a single expression contains
-#' an existing variable or a name-value pair.
+#' @param ... If empty, grouping the current index. If not empty, a single
+#' expression is required for either an existing variable or a name-value pair.
+#' A lambda expression is supported, for example `~ as.Date(.)` where `.` refers
+#' to the index variable.
 #' The index functions that can be used, but not limited:
 #' * [lubridate::year]: yearly aggregation
 #' * [yearquarter]: quarterly aggregation
 #' * [yearmonth]: monthly aggregation
 #' * [yearweek]: weekly aggregation
 #' * [as.Date] or [lubridate::as_date]: daily aggregation
-#' * [lubridate::ceiling_date], [lubridate::floor_date], or [lubridate::round_date]: 
+#' * [lubridate::ceiling_date], [lubridate::floor_date], or [lubridate::round_date]:
 #' fine-resolution aggregation
+#' * Extract time components functions, such as [lubridate::hour()] & [lubridate::day()]
 #' * other index functions from other packages
 #'
 #' @details
-#' * A `index_by()`-ed tsibble is indicated by `@` in the "Groups" when 
+#' * A `index_by()`-ed tsibble is indicated by `@` in the "Groups" when
 #' displaying on the screen.
 #'
 #' @rdname index-by
@@ -29,19 +35,19 @@
 #' pedestrian %>% index_by()
 #' # Monthly counts across sensors
 #' library(dplyr, warn.conflicts = FALSE)
-#' monthly_ped <- pedestrian %>% 
-#'   group_by_key() %>% 
-#'   index_by(Year_Month = yearmonth(Date_Time)) %>%
+#' monthly_ped <- pedestrian %>%
+#'   group_by_key() %>%
+#'   index_by(Year_Month = ~ yearmonth(.)) %>%
 #'   summarise(
 #'     Max_Count = max(Count),
 #'     Min_Count = min(Count)
 #'   )
 #' monthly_ped
 #' index(monthly_ped)
-#' 
+#'
 #' # Using existing variable
-#' pedestrian %>% 
-#'   group_by_key() %>% 
+#' pedestrian %>%
+#'   group_by_key() %>%
 #'   index_by(Date) %>%
 #'   summarise(
 #'     Max_Count = max(Count),
@@ -49,15 +55,15 @@
 #'   )
 #'
 #' # Attempt to aggregate to 4-hour interval, with the effects of DST
-#' pedestrian %>% 
-#'   group_by_key() %>% 
-#'   index_by(Date_Time4 = lubridate::floor_date(Date_Time, "4 hour")) %>%
+#' pedestrian %>%
+#'   group_by_key() %>%
+#'   index_by(Date_Time4 = ~ lubridate::floor_date(., "4 hour")) %>%
 #'   summarise(Total_Count = sum(Count))
 #'
 #' # Annual trips by Region and State
-#' tourism %>% 
-#'   index_by(Year = lubridate::year(Quarter)) %>% 
-#'   group_by(Region, State) %>% 
+#' tourism %>%
+#'   index_by(Year = ~ lubridate::year(.)) %>%
+#'   group_by(Region, State) %>%
 #'   summarise(Total = sum(Trips))
 index_by <- function(.data, ...) {
   UseMethod("index_by")
@@ -74,18 +80,24 @@ index_by.tbl_ts <- function(.data, ...) {
   if (identical(idx, names(exprs))) {
     abort(sprintf("Column `%s` (index) can't be overwritten.", idx))
   }
+  idx2_data <- ungrp <- ungroup(as_tibble(.data))
   if (is_empty(exprs)) {
     idx2 <- index(.data)
   } else {
     idx2 <- sym(names(quos_auto_name(exprs)))
+    expr <- exprs[[1]]
+    expr_f <- quo_get_expr(expr)
+    if (is_formula(expr_f)) { # lambda expression
+      f <- as_function(eval_bare(expr_f), env = quo_get_env(expr))
+      idx2_data <- mutate(ungrp, !!idx2 := f(!!sym(idx)))
+    } else {
+      idx2_data <- mutate(ungrp, !!idx2 := !!expr)
+    }
   }
-  tbl <- 
-    group_by(
-      mutate(ungroup(as_tibble(.data)), !!! exprs),
-      !!! groups(.data), !! idx2, .drop = FALSE
-    )
+  tbl <- group_by(idx2_data, !!!groups(.data), !!idx2, .drop = FALSE)
   build_tsibble(
-    tbl, key_data = key_data(.data), index = !! idx, index2 = !! idx2,
+    tbl,
+    key_data = key_data(.data), index = !!idx, index2 = !!idx2,
     ordered = is_ordered(.data), interval = interval(.data),
     validate = FALSE
   )
