@@ -1,5 +1,8 @@
 #' New tsibble data and append new observations to a tsibble
 #'
+#' @description
+#' \Sexpr[results=rd, stage=render]{tsibble:::lifecycle("stable")}
+#'
 #' @param .data A `tbl_ts`.
 #' @param n An integer indicates the number of key-index pair to append.
 #' @param ... Passed to individual S3 method.
@@ -30,21 +33,21 @@ new_data.tbl_ts <- function(.data, n = 1L, keep_all = FALSE, ...) {
   tunit <- time_unit(int)
 
   grped_df <- new_grouped_df(.data, groups = key_data(.data))
-  last_entry <- summarise(grped_df, !! idx := max(!! idx))
+  last_entry <- summarise(grped_df, !!idx := max(!!idx))
 
   nc <- NCOL(last_entry)
   new_lst <- new_list(NROW(last_entry))
   for (i in seq_len(NROW(last_entry))) {
-    lst_i <- new_lst[[i]] <- as_list(last_entry[i, ])
+    lst_i <- new_lst[[i]] <- as.list(last_entry[i, ])
     new_lst[[i]][[nc]] <- seq(lst_i[[nc]], by = tunit, length.out = n + 1)[-1]
     new_lst[[i]] <- as_tibble(new_lst[[i]])
   }
-  out <- dplyr::bind_rows(!!! new_lst)
+  out <- bind_rows(!!!new_lst)
   if (keep_all) {
-    out <- dplyr::bind_rows(.data[0L, ], out)
+    out <- bind_rows(.data[0L, ], out)
   } else { # reorder column names according to the data input
     cn <- setdiff(names(.data), measured_vars(.data))
-    out <- select(out, !!! cn)
+    out <- select(out, !!!cn)
   }
   update_meta(out, .data, ordered = TRUE, interval = interval(.data))
 }
@@ -58,7 +61,7 @@ new_data.tbl_ts <- function(.data, n = 1L, keep_all = FALSE, ...) {
 #' @export
 #' @examples
 #' tsbl <- tsibble(
-#'   date = rep(as.Date("2017-01-01") + 0:2, each = 2), 
+#'   date = rep(as.Date("2017-01-01") + 0:2, each = 2),
 #'   group = rep(letters[1:2], 3),
 #'   value = rnorm(6),
 #'   key = group
@@ -72,7 +75,7 @@ append_row <- function(.data, n = 1L, ...) {
 #' @export
 append_row.tbl_ts <- function(.data, n = 1L, ...) {
   new_data <- new_data(.data, n = n)
-  out <- dplyr::bind_rows(.data, new_data)
+  out <- bind_rows(.data, new_data)
   ord <- is_ordered(.data)
   if (ord) ord <- NULL # re-order
   update_meta(out, .data, ordered = ord, interval = interval(.data))
