@@ -25,7 +25,7 @@
   new_key <- cn[cn %in% key_vars(x)]
 
   if (!missing(i)) {
-    if (any_not_equal_to_c(anyDuplicated.default(i), 0)) return(as_tibble(res))
+    if (anyDuplicated.default(i) > 0) return(as_tibble(res))
   }
 
   not_tsibble <- !(index_var(x) %in% cn) || NROW(res) > NROW(x)
@@ -34,12 +34,14 @@
     as_tibble(res)
   } else if (index2_var(x) %in% names(res)) {
     build_tsibble(
-      res, key = !! new_key, index = !! index(x), index2 = !! index2(x),
+      res,
+      key = !!new_key, index = !!index(x), index2 = !!index2(x),
       interval = is_regular(x), ordered = is_ordered(x), validate = FALSE
     )
   } else { # index2 not there
     build_tsibble(
-      res, key = !! new_key, index = !! index(x), interval = is_regular(x),
+      res,
+      key = !!new_key, index = !!index(x), interval = is_regular(x),
       ordered = is_ordered(x), validate = FALSE
     )
   }
@@ -56,8 +58,8 @@
 #   exceed_rows(x, length(value))
 #
 #   if (n_args <= 3 && !missing(i)) { # x, i/j, value
-#     # x[i] <- 
-#     # x[, j] <- 
+#     # x[i] <-
+#     # x[, j] <-
 #     if (i > NCOL(x)) {
 #       i <- as.character(i)
 #       i <- vars_select(union(i, names(x)), i)
@@ -66,7 +68,7 @@
 #     }
 #     lst_i <- map(i, ~ (.x = value))
 #     mutate(x, !!! lst_i)
-#   } else { # x[i, j] <- 
+#   } else { # x[i, j] <-
 #     if (missing(i)) {
 #       i <- seq_len(NROW(x))
 #       res <- x
