@@ -1,4 +1,5 @@
 ## helpers
+is_ascending <- Negate(is.unsorted)
 
 min0 <- function(...) {
   min(..., na.rm = TRUE)
@@ -58,7 +59,7 @@ angle_brackets <- function(x) {
 # inlined from https://github.com/r-lib/cli/blob/master/R/utf8.R
 is_utf8_output <- function() {
   opt <- getOption("cli.unicode", NULL)
-  if (! is_null(opt)) {
+  if (!is_null(opt)) {
     isTRUE(opt)
   } else {
     l10n_info()$`UTF-8` && !is_latex_output()
@@ -66,7 +67,9 @@ is_utf8_output <- function() {
 }
 
 is_latex_output <- function() {
-  if (!("knitr" %in% loadedNamespaces())) return(FALSE)
+  if (!("knitr" %in% loadedNamespaces())) {
+    return(FALSE)
+  }
   get("is_latex_output", asNamespace("knitr"))()
 }
 
